@@ -67,6 +67,9 @@ class TransformAuth:  # noqa: D
 
         self.config.set_config_value(API_KEY_CONFIG_KEY, api_key)
 
+        # after setting a new API key, reset the user_state to reflect the new auth
+        self.reset_user_state()
+
     @property
     def bearer_token(self) -> Optional[str]:
         """Get bearer token from config, if exists."""
@@ -125,6 +128,14 @@ class TransformAuth:  # noqa: D
             self.__user_state = self.backend_client.get_user_state()
         return self.__user_state
 
+    def reset_user_state(self) -> None:
+        """Resets the auth_header & pulls new user_state to ensure context is updated.
+
+        Function is necessary to update old context ith new user_state when re-authenticating.
+        """
+        self.__auth_header = None
+        self.__user_state = self.backend_client.get_user_state()
+
     @property
     def org(self) -> Organization:  # noqa: D
         return self.user_state.organization
