@@ -213,6 +213,9 @@ class CLIContext(TransformAuth):
     def user_state(self) -> UserState:  # noqa: D
         if self.__user_state is None:
             try:
+                # if user state is none, first reset the context user_state as well prior to getting the identity from MQL
+                # If not, the user_state may not reflect the most recent auth login (for example, when already authenticated and you run 'mql setup' again, resetting user state is necessary)
+                self.mql.context.reset_user_state()
                 self.__user_state = self.mql.identify()
             except Exception as e:
                 # TODO: Figure out a better way to determine user's org is blocking API key use without doing hacky string matching!
@@ -264,8 +267,10 @@ class CLIContext(TransformAuth):
             current_config_path = str(Path(config_dir).resolve())
             current_config_modified = directory_last_edited(config_dir)
 
+            # TODO@jack Re-enable once bug tracked down or sufficiently mitigated.
             if (
-                last_config_path is not None
+                False
+                and last_config_path is not None
                 and last_config_modified is not None
                 and last_config_model_id is not None
                 and current_config_modified is not None
