@@ -8,7 +8,7 @@ from functools import wraps
 from typing import Any, Callable, List, Optional
 
 from ..constants import DEFAULT_QUERY_TIMEOUT
-from ..models import CacheMode, PercentChange, INF, NEGATIVE_ONE, DEFAULT_LIMIT, TimeGranularity
+from ..models import CacheMode, PercentChange, INF, NEGATIVE_ONE, DEFAULT_LIMIT, TimeGranularity, PrintStyle
 
 
 class PythonLiteralOption(click.Option):
@@ -96,6 +96,11 @@ def query_options(function: Callable) -> Callable:
         ),
         # Cast as CacheMode type
         callback=lambda ctx, param, value: CacheMode(value) if value is not None else None,
+        help="""Optional interface allowing you to control how it is reading and writing from Transform's cache.\n
+        [r] read from cached tables\n
+        [w] write to cached tables\n
+        [rw] read + write -- DEFAULT\n
+        [i] neither read nor write from cache""",
     )(function)
 
     function = click.option(
@@ -149,6 +154,18 @@ def query_options(function: Callable) -> Callable:
     )(function)
 
     function = start_end_time_options(function)
+
+    function = click.option(
+        "--style",
+        type=click.Choice(
+            list(map(lambda x: x.value, PrintStyle)),
+            case_sensitive=False,
+        ),
+        default="standard",
+        # Cast as PrintStyle type
+        callback=lambda ctx, param, value: PrintStyle(value) if value is not None else None,
+        help="Choose your print style. Default: standard",
+    )(function)
     return function
 
 
