@@ -6,14 +6,17 @@ import textwrap
 
 import pandas as pd
 from halo import Halo
+from rich.console import Console  # type: ignore
 from typing import Dict, List, Optional
 from datetime import datetime
+from packaging.version import parse
 
 from log_symbols import LogSymbols
-from packaging.version import parse
 from termcolor import colored
 from update_checker import UpdateChecker
 
+from ..pretty_pandas import prettify
+
 from ..interfaces import DWValidationType
 
 from .cli_context import CLIContext
@@ -33,6 +36,7 @@ from .cli_utils import (
 from ..models import (
     CacheMode,
     PercentChange,
+    PrintStyle,
     Query,
     HealthReportStatus,
     DEFAULT_LIMIT,
@@ -45,6 +49,8 @@ pass_config = click.make_pass_decorator(CLIContext, ensure=True)
 
 MAX_LIST_OBJECT_ELEMENTS = 5
 
+console = Console()
+
 
 @click.group()
 @click.option("-v", "--verbose", is_flag=True)
@@ -287,11 +293,7 @@ def health_report(config: CLIContext) -> None:
 @query_options
 @pass_config
 @click.pass_context
-@click.option(
-    "--as-table",
-    required=False,
-    type=str,
-)
+@click.option("--as-table", required=False, type=str, help="To write a table in your data warehouse")
 @click.option(
     "--csv",
     type=click.File("wb"),
@@ -337,6 +339,7 @@ def query(
     web: bool = False,
     debug: bool = False,
     allow_dynamic_cache: bool = True,
+    style: Optional[PrintStyle] = None,
 ) -> None:
     """Create a new MQL query, polls for completion and assembles a DataFrame from the response."""
     validate_query_args(limit)
@@ -391,6 +394,10 @@ def query(
 
     spinner.stop_and_persist(symbol=final_symbol.value, text=final_message)
 
+    warnings = config.mql.get_query_status(query_id).warnings
+    for warning in warnings:
+        click.echo(click.style("WARNING: ", fg="yellow") + warning)
+
     # Show the data if returned successfully
     if df is not None:
         if df.empty:
@@ -399,11 +406,34 @@ def query(
             df.to_csv(csv, index=False)
             click.echo(f"Successfully written query output to {csv.name}")
         else:
-            # NOTE: remove `to_string` if no pandas dependency is < 1.1.0
-            if parse(pd.__version__) >= parse("1.1.0"):
-                click.echo(df.to_markdown(index=False, floatfmt=f".{decimals}f"))
+            if style == PrintStyle.PRETTY:
+                # see pretty_pandas.py for df printing logic
+                pretty_df = prettify(
+                    df=df,
+                    metrics=metrics,
+                    dimensions=dimensions,
+                    time_constraint=time_constraint,
+                    time_granularity=time_granularity,
+                    time_comparison=time_comparison,
+                    order=order,
+                    start_time=start_time,
+                    end_time=end_time,
+                )
+
+                # must use rich print to print rich table as opposed to click.echo
+                console.print(pretty_df, justify="center")
             else:
-                click.echo(df.to_string(index=False, float_format=lambda x: format(x, f".{decimals}f")))
+                df_to_print = None
+                if parse(pd.__version__) >= parse("1.1.0"):
+                    df_to_print = df.to_markdown(index=False, floatfmt=f".{decimals}f")
+                else:
+                    df_to_print = df.to_string(index=False, float_format=lambda x: format(x, f".{decimals}f"))
+
+                if style == PrintStyle.STANDARD:
+                    # must use rich print to print rich table as opposed to click.echo
+                    console.print(df_to_print, justify="center")
+                else:
+                    click.echo(df_to_print)
 
     if web:
         click.launch(get_query_logs_url_for_id(query_id))
@@ -922,7 +952,7 @@ def commit_configs(
         promote_spinner = Halo(text="Promoting commited model to be primary", spinner="dots")
         promote_spinner.start()
         config.mql.promote_model(model)
-        promote_spinner.succeed(f"🚀 Success! Model {model.id} is now the primary model for you org")
+        promote_spinner.succeed(f"🚀 Success! Model {model.id} is now the primary model for your org")
 
     if pin is None:
         if click.confirm("📌 Would you like to pin this model commit for future MQL queries?"):
